﻿using Correo.Abstractions;
using MimeKit;
using System.Collections.Generic;

namespace Correo.MailKit.Extensions
{
    internal static class ModelExtensions
    {
        private static MailboxAddress ToMailboxAddress(this EmailMessage.MailAddress address)
            => new MailboxAddress(address.DisplayName, address.Address);

        private static void AddRange(this InternetAddressList list, IEnumerable<EmailMessage.MailAddress> addresses)
        {
            foreach (var item in addresses)
                list.Add(item.ToMailboxAddress());
        }

        public static MimeMessage ToMailMessage(this EmailMessage message)
        {
            var subtype = message.IsBodyHtml ? "html" : "plain";
            var mailMessage = new MimeMessage()
            {
                Subject = message.Subject,
                Body = new TextPart(subtype) { Text = message.Body }
            };

            mailMessage.From.Add(message.From.ToMailboxAddress());
            mailMessage.To.AddRange(message.To);
            mailMessage.Cc.AddRange(message.Cc);
            mailMessage.Bcc.AddRange(message.Bcc);

            return mailMessage;
        }
    }
}
