﻿using Correo.MailKit;
using Correo.SmtpClient;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using System;

namespace Correo.Extensions
{
    public static class SmtpExtensions
    {
        public static void AddSmtpClient(this IServiceCollection services, IConfiguration configuration)
        {
            var configSection = configuration.GetSection("SmtpClient");
            var mediator = configSection.GetValue("Mediator", ".NET");

            if (mediator.Equals(".NET", StringComparison.InvariantCultureIgnoreCase))
            {
                services.AddNetSmtpClient(configSection);
            }
            else if (mediator.Equals("MailKit", StringComparison.InvariantCultureIgnoreCase))
            {
                services.AddMailKitSmtpClient(configSection);
            }
            else
            {
                throw new NotImplementedException($"SmtpClient:Mediator={mediator} is not implemented.");
            }
        }
    }
}
